==> gnuyahoo_0.3.pre0.orig.tar.gz: gnuyahoo-0.3.pre0.orig/src/gnuyahoo.h <==
/* 
   gnuyahoo.h: header file for gnuyahoo(main file)
   
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2, or (at
   your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */


#define USERNAME_LENGTH 32
#define PASSWORD_LENGTH 32

#define GY_BUG_REPORT_EMAIL         "gnubot@yahoo.com"
#define GY_BUG_REPORT_ID            "gnubot"
#define GY_ROBOT                    "gnubot"
#define GY_ROBOT_GROUP              "GNU"

#define GY_PROMPT_STRING            "GY!> "
#define GY_CONFIG_DIRECTORY         "." PACKAGE
#define GY_CONFIG_DIRECTORY_MODE    S_IRWXU
#define GY_CONFIG_FILE              GY_CONFIG_DIRECTORY "/" PACKAGE ".scm"
#define GY_CONFIG_FILE_MODE         S_IRWXU
#define GY_DEFAULT_CONFIG_DIRECTORY PATH_CFG "/" PACKAGE
#define GY_DEFAULT_CONFIG_FILE      GY_DEFAULT_CONFIG_DIRECTORY "/" PACKAGE
#define GY_DOWNLOADS_URL_FILE       "downloads.url"
#define GY_DEFAULT_GROUP            "Friends"
#define GY_DEFAULT_STATUS           YAHOO_STATUS_AVAILABLE

#define GY_GLOBAL_EXTENSIONS_DIRECTORY DATADIR "/" PACKAGE "/extensions"
#define GY_LOCAL_EXTENSIONS_DIRECTORY  GY_CONFIG_DIRECTORY "/extensions"
#define GY_INIT_FILE                   "init.scm"
#define GY_GLOBAL_INIT_FILE            GY_GLOBAL_EXTENSIONS_DIRECTORY "/" GY_INIT_FILE

#define UTC_TIME_STR_SIZE              30
#define UTC_TIME_STR_FORMAT            "%a %b %d %X UTC %G"

char *get_default_login_id (void);
void set_default_login_id (char *default_login_id_value);
char *get_default_password (void);
void set_default_password (char *default_password_value);
char *get_default_prompt (void);
void set_default_prompt (char *prompt_default_value);
int get_setup_mode (void);
void set_setup_mode (int setup_mode_value);

==> gnuyahoo_1.0.1.orig.tar.gz: gnuyahoo-1.0.1/src/gnuyahoo.h <==
/* 
   gnuyahoo.h: header file for gnuyahoo(main file)
   
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2, or (at
   your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */

#ifndef _GNUYAHOO_H
#define _GNUYAHOO_H


#define USERNAME_LENGTH 32
#define PASSWORD_LENGTH 32

#define GY_BUG_REPORT_EMAIL         "gnubot@yahoo.com"
#define GY_BUG_REPORT_ID            "gnubot"
#define GY_ROBOT                    "gnubot"
#define GY_ROBOT_GROUP              "GNU"

#define GY_PROMPT_STRING            "GY!> "
#define GY_CONFIG_DIRECTORY         "." PACKAGE
#define GY_CONFIG_DIRECTORY_MODE    S_IRWXU
#define GY_CONFIG_FILE              GY_CONFIG_DIRECTORY "/" PACKAGE ".scm"
#define GY_CONFIG_FILE_MODE         S_IRWXU
#define GY_DEFAULT_CONFIG_DIRECTORY PATH_CFG "/" PACKAGE
#define GY_DEFAULT_CONFIG_FILE      GY_DEFAULT_CONFIG_DIRECTORY "/" PACKAGE
#define GY_DOWNLOADS_DIRECTORY      "downloads"
#define GY_DOWNLOADS_URL_FILE       "downloads.url"
#define GY_DEFAULT_GROUP            "Friends"
#define GY_DEFAULT_STATUS           YAHOO_STATUS_AVAILABLE

#define GY_GLOBAL_EXTENSIONS_DIRECTORY DATADIR "/" PACKAGE "/extensions"
#define GY_LOCAL_EXTENSIONS_DIRECTORY  GY_CONFIG_DIRECTORY "/extensions"
#define GY_INIT_FILE                   "init.scm"
#define GY_GLOBAL_INIT_FILE            GY_GLOBAL_EXTENSIONS_DIRECTORY "/" GY_INIT_FILE

#define UTC_TIME_STR_SIZE              30
#define UTC_TIME_STR_FORMAT            "%a %b %d %X UTC %G"

#define GY_DEFAULT_CONFIG_CONTENTS     \
";;; Gnuyahoo loads the startup options from `~/.gnuyahoo/gnuyahoo.scm'.\n\
;;; Right from custom settings like username, password ... to complete\n\
;;; Scheme programming can be done in this file.\n\
;;; All entries in this `gnuyahoo.scm' file are optional.  How ever\n\
;;; there is no limit in customizing or extending Gnuyahoo through Guile\n\
;;; interface. Please refer info pages with command \n\
;;; `info gnuyahoo Customization gnuyahoo.scm'\n"

char *get_default_login_id (void);
void set_default_login_id (char *default_login_id_value);
char *get_default_password (void);
void set_default_password (char *default_password_value);
char *get_default_prompt (void);
void set_default_prompt (char *prompt_default_value);
int get_setup_mode (void);
void set_setup_mode (int setup_mode_value);

#endif
